# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: put_schedule.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import date_pb2 as date__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x12put_schedule.proto\x12\x06\x62\x61nchi\x1a\ndate.proto\"}\n\x03Put\x12 \n\nfirst_date\x18\x01 \x01(\x0b\x32\x0c.banchi.Date\x12 \n\nfinal_date\x18\x02 \x01(\x0b\x32\x0c.banchi.Date\x12\r\n\x05level\x18\x03 \x01(\x01\"#\n\nLevelBasis\x12\x07\n\x03PAR\x10\x00\x12\x0c\n\x08\x41\x43\x43RETED\x10\x01\"v\n\x0bPutSchedule\x12\x1d\n\x08schedule\x18\x01 \x03(\x0b\x32\x0b.banchi.Put\x12\x17\n\x0f\x66orfeit_accrued\x18\x02 \x01(\x08\x12/\n\x0fput_level_basis\x18\x05 \x01(\x0e\x32\x16.banchi.Put.LevelBasisb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'put_schedule_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _PUT._serialized_start=42
  _PUT._serialized_end=167
  _PUT_LEVELBASIS._serialized_start=132
  _PUT_LEVELBASIS._serialized_end=167
  _PUTSCHEDULE._serialized_start=169
  _PUTSCHEDULE._serialized_end=287
# @@protoc_insertion_point(module_scope)
