# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: enums.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0b\x65nums.proto\x12\x06\x62\x61nchi\"5\n\x03\x41lt\".\n\x0c\x43urrencyType\x12\x0e\n\nINSTRUMENT\x10\x00\x12\x0e\n\nUNDERLYING\x10\x01*2\n\x14\x45xerciseScheduleType\x12\x0c\n\x08\x45UROPEAN\x10\x00\x12\x0c\n\x08\x41MERICAN\x10\x01*x\n\x0b\x43ompounding\x12\x0e\n\nCONTINUOUS\x10\x00\x12\n\n\x06\x41NNUAL\x10\x01\x12\x0e\n\nSEMIANNUAL\x10\x02\x12\r\n\tQUARTERLY\x10\x03\x12\x0b\n\x07MONTHLY\x10\x04\x12\n\n\x06WEEKLY\x10\x05\x12\t\n\x05\x44\x41ILY\x10\x06\x12\n\n\x06SIMPLE\x10\n*b\n\x10PaymentFrequency\x12\x11\n\rPAID_ANNUALLY\x10\x00\x12\x15\n\x11PAID_SEMIANNUALLY\x10\x01\x12\x12\n\x0ePAID_QUARTERLY\x10\x02\x12\x10\n\x0cPAID_MONTHLY\x10\x03*8\n\x11ReferenceRateType\x12\x19\n\x15\x43OMPOUNDED_IN_ARREARS\x10\x00\x12\x08\n\x04TERM\x10\x01*%\n\x08\x44\x61ysType\x12\x0c\n\x08\x43\x41LENDAR\x10\x00\x12\x0b\n\x07TRADING\x10\x01*A\n\x0b\x46XRateBasis\x12\x18\n\x14\x46OREIGN_PER_DOMESTIC\x10\x00\x12\x18\n\x14\x44OMESTIC_PER_FOREIGN\x10\x01*V\n\x16\x43ontractualFXRateBasis\x12\x1d\n\x19INSTRUMENT_PER_UNDERLYING\x10\x00\x12\x1d\n\x19UNDERLYING_PER_INSTRUMENT\x10\x01*.\n\x0c\x43urrencyType\x12\x0e\n\nUNDERLYING\x10\x00\x12\x0e\n\nINSTRUMENT\x10\x01*k\n\x0eRollConvention\x12\x0b\n\x07NO_ROLL\x10\x00\x12\r\n\tFOLLOWING\x10\x01\x12\x16\n\x12MODIFIED_FOLLOWING\x10\x02\x12\r\n\tPRECEDING\x10\x03\x12\x16\n\x12MODIFIED_PRECEDING\x10\x04*c\n\x17SharePriceReferenceType\x12\x0f\n\x0b\x43LOSE_PRICE\x10\x00\x12\x0e\n\nOPEN_PRICE\x10\x01\x12\x0e\n\nHIGH_PRICE\x10\x02\x12\r\n\tLOW_PRICE\x10\x03\x12\x08\n\x04VWAP\x10\x04*Q\n\x13\x46XRateReferenceType\x12\x0e\n\nCLOSE_RATE\x10\x00\x12\r\n\tOPEN_RATE\x10\x01\x12\r\n\tHIGH_RATE\x10\x02\x12\x0c\n\x08LOW_RATE\x10\x03\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'enums_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _EXERCISESCHEDULETYPE._serialized_start=78
  _EXERCISESCHEDULETYPE._serialized_end=128
  _COMPOUNDING._serialized_start=130
  _COMPOUNDING._serialized_end=250
  _PAYMENTFREQUENCY._serialized_start=252
  _PAYMENTFREQUENCY._serialized_end=350
  _REFERENCERATETYPE._serialized_start=352
  _REFERENCERATETYPE._serialized_end=408
  _DAYSTYPE._serialized_start=410
  _DAYSTYPE._serialized_end=447
  _FXRATEBASIS._serialized_start=449
  _FXRATEBASIS._serialized_end=514
  _CONTRACTUALFXRATEBASIS._serialized_start=516
  _CONTRACTUALFXRATEBASIS._serialized_end=602
  _CURRENCYTYPE._serialized_start=604
  _CURRENCYTYPE._serialized_end=650
  _ROLLCONVENTION._serialized_start=652
  _ROLLCONVENTION._serialized_end=759
  _SHAREPRICEREFERENCETYPE._serialized_start=761
  _SHAREPRICEREFERENCETYPE._serialized_end=860
  _FXRATEREFERENCETYPE._serialized_start=862
  _FXRATEREFERENCETYPE._serialized_end=943
  _ALT._serialized_start=23
  _ALT._serialized_end=76
  _ALT_CURRENCYTYPE._serialized_start=30
  _ALT_CURRENCYTYPE._serialized_end=76
# @@protoc_insertion_point(module_scope)
