# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: output.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0coutput.proto\x12\x06\x62\x61nchi\"\x84\x01\n\nOutputInfo\x12\x11\n\trequested\x18\x01 \x01(\x08\x12\x0f\n\x07message\x18\x02 \x01(\t\x12)\n\x06status\x18\x03 \x01(\x0e\x32\x19.banchi.OutputInfo.Status\"\'\n\x06Status\x12\t\n\x05UNSET\x10\x00\x12\x07\n\x03SET\x10\x01\x12\t\n\x05\x45RROR\x10\x02\"?\n\x0cOutputDouble\x12\r\n\x05value\x18\x01 \x01(\x01\x12 \n\x04info\x18\x02 \x01(\x0b\x32\x12.banchi.OutputInfo\"=\n\nOutputBool\x12\r\n\x05value\x18\x01 \x01(\x08\x12 \n\x04info\x18\x02 \x01(\x0b\x32\x12.banchi.OutputInfob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'output_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _OUTPUTINFO._serialized_start=25
  _OUTPUTINFO._serialized_end=157
  _OUTPUTINFO_STATUS._serialized_start=118
  _OUTPUTINFO_STATUS._serialized_end=157
  _OUTPUTDOUBLE._serialized_start=159
  _OUTPUTDOUBLE._serialized_end=222
  _OUTPUTBOOL._serialized_start=224
  _OUTPUTBOOL._serialized_end=285
# @@protoc_insertion_point(module_scope)
