# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make_whole.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import date_pb2 as date__pb2
import enums_pb2 as enums__pb2
import matrix_pb2 as matrix__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x10make_whole.proto\x12\x06\x62\x61nchi\x1a\ndate.proto\x1a\x0b\x65nums.proto\x1a\x0cmatrix.proto\"\xd8\x07\n\tMakeWhole\x12*\n\x08schedule\x18\x01 \x03(\x0b\x32\x18.banchi.MakeWhole.Period\x12\x15\n\rtable_strikes\x18\x03 \x03(\x01\x12!\n\x0btable_dates\x18\x04 \x03(\x0b\x32\x0c.banchi.Date\x12*\n\x0ctable_values\x18\x05 \x01(\x0b\x32\x14.banchi.DoubleMatrix\x12:\n\x10table_value_type\x18\x06 \x01(\x0e\x32 .banchi.MakeWhole.TableValueType\x12\x33\n\x15table_strike_currency\x18\x0c \x01(\x0e\x32\x14.banchi.CurrencyType\x12\x42\n\x14\x63oupon_discount_type\x18\x07 \x01(\x0e\x32$.banchi.MakeWhole.CouponDiscountType\x12\x38\n\x1b\x63oupon_discount_compounding\x18\x08 \x01(\x0e\x32\x13.banchi.Compounding\x12\x33\n\x19\x63oupon_discount_day_count\x18\t \x01(\x0e\x32\x10.banchi.DayCount\x1a\xb0\x02\n\x06Period\x12 \n\nfirst_date\x18\x01 \x01(\x0b\x32\x0c.banchi.Date\x12 \n\nfinal_date\x18\x02 \x01(\x0b\x32\x0c.banchi.Date\x12$\n\x04type\x18\x03 \x01(\x0e\x32\x16.banchi.MakeWhole.Type\x12\x0f\n\x07on_call\x18\x06 \x01(\x08\x12\x15\n\ron_conversion\x18\x07 \x01(\x08\x12\x1c\n\x14on_forced_conversion\x18\x08 \x01(\x08\x12\x13\n\x0bon_takeover\x18\t \x01(\x08\x12\x15\n\rinitial_value\x18\x0b \x01(\x01\x12\x14\n\x0c\x64\x65\x63rement_by\x18\x0c \x01(\x01\x12\x17\n\x0f\x64iscount_spread\x18\x0e \x01(\x01\x12\x15\n\rdiscount_rate\x18\x10 \x01(\x01J\x04\x08\x0f\x10\x10\"k\n\x04Type\x12\x17\n\x13REMAINING_COUPON_PV\x10\x00\x12\x14\n\x10\x43OUPON_DECREMENT\x10\x01\x12\x14\n\x10\x41NNUAL_DECREMENT\x10\x02\x12\x13\n\x0f\x44\x41ILY_DECREMENT\x10\x03\x12\t\n\x05TABLE\x10\t\"4\n\x0eTableValueType\x12\x10\n\x0c\x45XTRA_SHARES\x10\x00\x12\x10\n\x0cTOTAL_SHARES\x10\x01\"?\n\x12\x43ouponDiscountType\x12\x0e\n\nFIXED_RATE\x10\x00\x12\x19\n\x15SPREAD_OVER_BENCHMARK\x10\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make_whole_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _MAKEWHOLE._serialized_start=68
  _MAKEWHOLE._serialized_end=1052
  _MAKEWHOLE_PERIOD._serialized_start=520
  _MAKEWHOLE_PERIOD._serialized_end=824
  _MAKEWHOLE_TYPE._serialized_start=826
  _MAKEWHOLE_TYPE._serialized_end=933
  _MAKEWHOLE_TABLEVALUETYPE._serialized_start=935
  _MAKEWHOLE_TABLEVALUETYPE._serialized_end=987
  _MAKEWHOLE_COUPONDISCOUNTTYPE._serialized_start=989
  _MAKEWHOLE_COUPONDISCOUNTTYPE._serialized_end=1052
# @@protoc_insertion_point(module_scope)
