# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: query.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import object_info_pb2 as object__info__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0bquery.proto\x12\x06\x62\x61nchi\x1a\x11object_info.proto\"\x1d\n\x0fPrecannedFilter\x12\n\n\x02id\x18\x01 \x01(\t\"\x87\x02\n\x0cSimpleFilter\x12\x16\n\x0e\x61ttribute_name\x18\x01 \x01(\t\x12)\n\x02op\x18\x02 \x01(\x0e\x32\x1d.banchi.SimpleFilter.Operator\x12\r\n\x05value\x18\x03 \x01(\t\"\xa4\x01\n\x08Operator\x12\x0c\n\x08\x43ONTAINS\x10\x00\x12\x14\n\x10\x44OES_NOT_CONTAIN\x10\x01\x12\n\n\x06\x45QUALS\x10\x02\x12\x12\n\x0e\x44OES_NOT_EQUAL\x10\x03\x12\x10\n\x0cGREATER_THAN\x10\x04\x12\x1a\n\x16GREATER_THAN_OR_EQUALS\x10\x05\x12\r\n\tLESS_THAN\x10\x06\x12\x17\n\x13LESS_THAN_OR_EQUALS\x10\x07\"\x1d\n\x0e\x41\x64vancedFilter\x12\x0b\n\x03str\x18\x01 \x01(\t\"\xe4\x01\n\x06\x46ilter\x12\'\n\x04type\x18\x03 \x01(\x0e\x32\x19.banchi.Filter.FilterType\x12*\n\tprecanned\x18\x04 \x01(\x0b\x32\x17.banchi.PrecannedFilter\x12$\n\x06simple\x18\x05 \x01(\x0b\x32\x14.banchi.SimpleFilter\x12(\n\x08\x61\x64vanced\x18\x06 \x01(\x0b\x32\x16.banchi.AdvancedFilter\"5\n\nFilterType\x12\r\n\tPRECANNED\x10\x00\x12\n\n\x06SIMPLE\x10\x01\x12\x0c\n\x08\x41\x44VANCED\x10\x02\"x\n\x0cQueryElement\x12\x1e\n\x06\x66ilter\x18\x01 \x01(\x0b\x32\x0e.banchi.Filter\x12*\n\x02op\x18\x02 \x01(\x0e\x32\x1e.banchi.QueryElement.LogicalOp\"\x1c\n\tLogicalOp\x12\x07\n\x03\x41ND\x10\x00\x12\x06\n\x02OR\x10\x01\"r\n\x05Query\x12\"\n\x06object\x18\x02 \x01(\x0b\x32\x12.banchi.ObjectInfo\x12&\n\x08\x65lements\x18\x04 \x03(\x0b\x32\x14.banchi.QueryElement\x12\x11\n\tobj_types\x18\x05 \x03(\tJ\x04\x08\x01\x10\x02J\x04\x08\x03\x10\x04\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'query_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _PRECANNEDFILTER._serialized_start=42
  _PRECANNEDFILTER._serialized_end=71
  _SIMPLEFILTER._serialized_start=74
  _SIMPLEFILTER._serialized_end=337
  _SIMPLEFILTER_OPERATOR._serialized_start=173
  _SIMPLEFILTER_OPERATOR._serialized_end=337
  _ADVANCEDFILTER._serialized_start=339
  _ADVANCEDFILTER._serialized_end=368
  _FILTER._serialized_start=371
  _FILTER._serialized_end=599
  _FILTER_FILTERTYPE._serialized_start=546
  _FILTER_FILTERTYPE._serialized_end=599
  _QUERYELEMENT._serialized_start=601
  _QUERYELEMENT._serialized_end=721
  _QUERYELEMENT_LOGICALOP._serialized_start=693
  _QUERYELEMENT_LOGICALOP._serialized_end=721
  _QUERY._serialized_start=723
  _QUERY._serialized_end=837
# @@protoc_insertion_point(module_scope)
