# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: fx_rate.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import currency_pb2 as currency__pb2
import enums_pb2 as enums__pb2
import object_info_pb2 as object__info__pb2
import ticker_pb2 as ticker__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\rfx_rate.proto\x12\x06\x62\x61nchi\x1a\x0e\x63urrency.proto\x1a\x0b\x65nums.proto\x1a\x11object_info.proto\x1a\x0cticker.proto\"\xb6\x01\n\x10\x46XTimeSeriesData\x12\'\n\nopen_rates\x18\x01 \x01(\x0b\x32\x13.banchi.DailyTicker\x12\'\n\nhigh_rates\x18\x02 \x01(\x0b\x32\x13.banchi.DailyTicker\x12&\n\tlow_rates\x18\x03 \x01(\x0b\x32\x13.banchi.DailyTicker\x12(\n\x0b\x63lose_rates\x18\x04 \x01(\x0b\x32\x13.banchi.DailyTicker\"\x84\x02\n\x06\x46XRate\x12\"\n\x06object\x18\r \x01(\x0b\x32\x12.banchi.ObjectInfo\x12\x11\n\tspot_rate\x18\x01 \x01(\x01\x12\'\n\nrate_basis\x18\x02 \x01(\x0e\x32\x13.banchi.FXRateBasis\x12\x12\n\nvolatility\x18\x03 \x01(\x01\x12-\n\x0btime_series\x18\x05 \x01(\x0b\x32\x18.banchi.FXTimeSeriesData\x12+\n\x11\x64omestic_currency\x18\x08 \x01(\x0b\x32\x10.banchi.Currency\x12*\n\x10\x66oreign_currency\x18\t \x01(\x0b\x32\x10.banchi.Currencyb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'fx_rate_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _FXTIMESERIESDATA._serialized_start=88
  _FXTIMESERIESDATA._serialized_end=270
  _FXRATE._serialized_start=273
  _FXRATE._serialized_end=533
# @@protoc_insertion_point(module_scope)
