# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: warrant_call_schedule.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import date_pb2 as date__pb2
import trigger_pb2 as trigger__pb2
import enums_pb2 as enums__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1bwarrant_call_schedule.proto\x12\x06\x62\x61nchi\x1a\ndate.proto\x1a\rtrigger.proto\x1a\x0b\x65nums.proto\"\xb8\x02\n\x12WarrantCallTrigger\x12\r\n\x05level\x18\x01 \x01(\x01\x12\"\n\x04type\x18\x03 \x01(\x0e\x32\x14.banchi.Trigger.Type\x12\x35\n\x0egrace_required\x18\x06 \x01(\x0e\x32\x1d.banchi.Trigger.GraceRequired\x12\x1c\n\x14\x64\x61ys_in_grace_period\x18\x07 \x01(\x05\x12\x14\n\x0cgrace_period\x18\x08 \x01(\x05\x12\x30\n\x16grace_period_days_type\x18\t \x01(\x0e\x32\x10.banchi.DaysType\x12\x1a\n\x12grace_period_delay\x18\x0c \x01(\x05\x12\x36\n\x1cgrace_period_delay_days_type\x18\r \x01(\x0e\x32\x10.banchi.DaysType\"\x8f\x02\n\x0bWarrantCall\x12 \n\nfirst_date\x18\x01 \x01(\x0b\x32\x0c.banchi.Date\x12 \n\nfinal_date\x18\x02 \x01(\x0b\x32\x0c.banchi.Date\x12\r\n\x05level\x18\x04 \x01(\x01\x12+\n\x07trigger\x18\x05 \x01(\x0b\x32\x1a.banchi.WarrantCallTrigger\x12\x16\n\x0eminimum_notice\x18\n \x01(\x05\x12\x16\n\x0emaximum_notice\x18\x0b \x01(\x05\x12*\n\x10notice_days_type\x18\x0c \x01(\x0e\x32\x10.banchi.DaysType\x12$\n\x1c\x63\x61shless_exercise_applicable\x18\x0f \x01(\x08\"\x8d\x02\n\x13WarrantCallSchedule\x12%\n\x08schedule\x18\x01 \x03(\x0b\x32\x13.banchi.WarrantCall\x12\x46\n\x1dtrigger_share_price_reference\x18\x06 \x01(\x0e\x32\x1f.banchi.SharePriceReferenceType\x12\x39\n\x14trigger_fx_reference\x18\x07 \x01(\x0e\x32\x1b.banchi.FXRateReferenceType\x12\x17\n\x0f\x65xercise_expiry\x18\x0e \x01(\x05\x12\x33\n\x19\x65xercise_expiry_days_type\x18\x0f \x01(\x0e\x32\x10.banchi.DaysTypeb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'warrant_call_schedule_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _WARRANTCALLTRIGGER._serialized_start=80
  _WARRANTCALLTRIGGER._serialized_end=392
  _WARRANTCALL._serialized_start=395
  _WARRANTCALL._serialized_end=666
  _WARRANTCALLSCHEDULE._serialized_start=669
  _WARRANTCALLSCHEDULE._serialized_end=938
# @@protoc_insertion_point(module_scope)
