# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: market_news.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import date_pb2 as date__pb2
import object_info_pb2 as object__info__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x11market_news.proto\x12\x06\x62\x61nchi\x1a\ndate.proto\x1a\x11object_info.proto\"\xec\x01\n\nMarketNews\x12\"\n\x06object\x18\x02 \x01(\x0b\x32\x12.banchi.ObjectInfo\x12*\n\tnews_type\x18\x03 \x01(\x0e\x32\x17.banchi.MarketNews.Type\x12\x0f\n\x07\x64\x65tails\x18\x04 \x01(\t\x12\x0b\n\x03url\x18\x05 \x01(\t\x12\x1a\n\x04\x64\x61te\x18\x06 \x01(\x0b\x32\x0c.banchi.Date\"N\n\x04Type\x12\x0c\n\x08MARKETUP\x10\x00\x12\x0e\n\nMARKETDOWN\x10\x02\x12\x0e\n\nMARKETFLAT\x10\x03\x12\n\n\x06REPORT\x10\x04\x12\x0c\n\x08NEWISSUE\x10\x05J\x04\x08\x01\x10\x02\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'market_news_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _MARKETNEWS._serialized_start=61
  _MARKETNEWS._serialized_end=297
  _MARKETNEWS_TYPE._serialized_start=213
  _MARKETNEWS_TYPE._serialized_end=291
# @@protoc_insertion_point(module_scope)
