# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: credit_data.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import enums_pb2 as enums__pb2
import yield_curve_pb2 as yield__curve__pb2
import object_info_pb2 as object__info__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x11\x63redit_data.proto\x12\x06\x62\x61nchi\x1a\x0b\x65nums.proto\x1a\x11yield_curve.proto\x1a\x11object_info.proto\"\xb4\x02\n\nCreditData\x12\"\n\x06object\x18\r \x01(\x0b\x32\x12.banchi.ObjectInfo\x12%\n\x04type\x18\x03 \x01(\x0e\x32\x17.banchi.CreditData.Type\x12\x13\n\x0b\x66lat_spread\x18\x04 \x01(\x01\x12/\n\x12spread_compounding\x18\x06 \x01(\x0e\x32\x13.banchi.Compounding\x12*\n\x0eterm_structure\x18\x07 \x03(\x0b\x32\x12.banchi.CurveEntry\x12\'\n\x0brisky_curve\x18\x08 \x01(\x0b\x32\x12.banchi.YieldCurve\":\n\x04Type\x12\x0f\n\x0b\x46LAT_SPREAD\x10\x00\x12\x10\n\x0cTERM_SPREADS\x10\x01\x12\x0f\n\x0bRISKY_CURVE\x10\x02J\x04\x08\x01\x10\x02\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'credit_data_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _CREDITDATA._serialized_start=81
  _CREDITDATA._serialized_end=389
  _CREDITDATA_TYPE._serialized_start=325
  _CREDITDATA_TYPE._serialized_end=383
# @@protoc_insertion_point(module_scope)
