# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: model_parameters.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x16model_parameters.proto\x12\x06\x62\x61nchi\"t\n\x0fModelParameters\x12\x37\n\x13\x64iscretisation_type\x18\x01 \x01(\x0e\x32\x1a.banchi.DiscretisationType\x12\x12\n\ntime_steps\x18\x03 \x01(\x05\x12\x14\n\x0cstock_points\x18\x04 \x01(\x05*E\n\x12\x44iscretisationType\x12\x0c\n\x08\x42\x41LANCED\x10\x00\x12\n\n\x06SPARSE\x10\x01\x12\t\n\x05\x44\x45NSE\x10\x02\x12\n\n\x06MANUAL\x10\tb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'model_parameters_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _DISCRETISATIONTYPE._serialized_start=152
  _DISCRETISATIONTYPE._serialized_end=221
  _MODELPARAMETERS._serialized_start=34
  _MODELPARAMETERS._serialized_end=150
# @@protoc_insertion_point(module_scope)
