# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: interest_rate_index.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import date_pb2 as date__pb2
import object_info_pb2 as object__info__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x19interest_rate_index.proto\x12\x06\x62\x61nchi\x1a\ndate.proto\x1a\x11object_info.proto\"6\n\nFixingRate\x12\x1a\n\x04\x64\x61te\x18\x01 \x01(\x0b\x32\x0c.banchi.Date\x12\x0c\n\x04rate\x18\x02 \x01(\x01\"\x95\x01\n\x11InterestRateIndex\x12\"\n\x06object\x18\r \x01(\x0b\x32\x12.banchi.ObjectInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12#\n\x07\x66ixings\x18\x03 \x03(\x0b\x32\x12.banchi.FixingRate\x12#\n\tday_count\x18\x06 \x01(\x0e\x32\x10.banchi.DayCountJ\x04\x08\x01\x10\x02\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'interest_rate_index_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _FIXINGRATE._serialized_start=68
  _FIXINGRATE._serialized_end=122
  _INTERESTRATEINDEX._serialized_start=125
  _INTERESTRATEINDEX._serialized_end=274
# @@protoc_insertion_point(module_scope)
