# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: calendar.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import date_pb2 as date__pb2
import object_info_pb2 as object__info__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0e\x63\x61lendar.proto\x12\x06\x62\x61nchi\x1a\ndate.proto\x1a\x11object_info.proto\"\x87\x01\n\x08\x43\x61lendar\x12\"\n\x08weekends\x18\x02 \x01(\x0e\x32\x10.banchi.Weekends\x12\x1e\n\x08holidays\x18\x03 \x03(\x0b\x32\x0c.banchi.Date\x12\"\n\x06object\x18\r \x01(\x0b\x32\x12.banchi.ObjectInfo\x12\x13\n\x0b\x64\x65scription\x18\x0e \x01(\t*$\n\x08Weekends\x12\x0b\n\x07SAT_SUN\x10\x00\x12\x0b\n\x07\x46RI_SAT\x10\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'calendar_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _WEEKENDS._serialized_start=195
  _WEEKENDS._serialized_end=231
  _CALENDAR._serialized_start=58
  _CALENDAR._serialized_end=193
# @@protoc_insertion_point(module_scope)
