# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bond.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import date_pb2 as date__pb2
import enums_pb2 as enums__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\nbond.proto\x12\x06\x62\x61nchi\x1a\ndate.proto\x1a\x0b\x65nums.proto\x1a\x1egoogle/protobuf/wrappers.proto\"\xcd\x01\n\rCouponDetails\x12\x37\n\trate_type\x18\x01 \x01(\x0e\x32$.banchi.CouponDetails.CouponRateType\x12\x12\n\nfixed_rate\x18\x02 \x01(\x01\x12+\n\tfrequency\x18\x04 \x01(\x0e\x32\x18.banchi.PaymentFrequency\x12\x17\n\x0f\x66loating_spread\x18\n \x01(\x01\")\n\x0e\x43ouponRateType\x12\t\n\x05\x46IXED\x10\x00\x12\x0c\n\x08\x46LOATING\x10\x01\"V\n\x0c\x43ouponStream\x12\x1e\n\x08\x65nd_date\x18\x02 \x01(\x0b\x32\x0c.banchi.Date\x12&\n\x07\x64\x65tails\x18\x03 \x01(\x0b\x32\x15.banchi.CouponDetails\"\x96\x01\n\x0f\x42ondMarketPrice\x12\r\n\x05price\x18\x01 \x01(\x01\x12\r\n\x05\x64irty\x18\x02 \x01(\x08\x12\x35\n\nquote_type\x18\x03 \x01(\x0e\x32!.banchi.BondMarketPrice.QuoteType\".\n\tQuoteType\x12\x17\n\x13PERCENT_OF_NOTIONAL\x10\x00\x12\x08\n\x04\x43\x41SH\x10\x01\"\x9f\x08\n\x0b\x42ondDetails\x12 \n\nissue_date\x18\x02 \x01(\x0b\x32\x0c.banchi.Date\x12#\n\rmaturity_date\x18\x03 \x01(\x0b\x32\x0c.banchi.Date\x12\x10\n\x08notional\x18\x04 \x01(\x01\x12\x1e\n\x16use_structured_coupons\x18\x06 \x01(\x08\x12\x32\n\x13\x66lat_coupon_details\x18\x07 \x01(\x0b\x32\x15.banchi.CouponDetails\x12,\n\x0e\x63oupon_streams\x18\x08 \x03(\x0b\x32\x14.banchi.CouponStream\x12+\n\x11\x61\x63\x63rual_day_count\x18\t \x01(\x0e\x32\x10.banchi.DayCount\x12\x1b\n\x13settlement_interval\x18\x0b \x01(\x05\x12\x14\n\x0cis_perpetual\x18\x0c \x01(\x08\x12?\n\x1c\x66loating_reference_rate_type\x18\r \x01(\x0e\x32\x19.banchi.ReferenceRateType\x12\x30\n\taccretion\x18\x0f \x01(\x0b\x32\x1d.banchi.BondDetails.Accretion\x12\x33\n\rissue_percent\x18\x10 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12\x36\n\x10maturity_percent\x18\x11 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12\x37\n\x17payment_roll_convention\x18\x14 \x01(\x0e\x32\x16.banchi.RollConvention\x1a\xbb\x03\n\tAccretion\x12\x45\n\x0f\x64\x65\x66inition_type\x18\x01 \x01(\x0e\x32,.banchi.BondDetails.Accretion.DefinitionType\x12(\n\x08schedule\x18\x02 \x03(\x0b\x32\x16.banchi.StartDateValue\x12\x1e\n\x08\x65nd_date\x18\x03 \x01(\x0b\x32\x0c.banchi.Date\x12\x39\n\trate_type\x18\x05 \x01(\x0e\x32&.banchi.BondDetails.Accretion.RateType\x12-\n\x10rate_compounding\x18\x06 \x01(\x0e\x32\x13.banchi.Compounding\x12(\n\x0erate_day_count\x18\x07 \x01(\x0e\x32\x10.banchi.DayCount\"Z\n\x0e\x44\x65\x66initionType\x12\x08\n\x04NONE\x10\x00\x12\x14\n\x10\x46IXED_FROM_ISSUE\x10\x01\x12\x15\n\x11\x46IXED_TO_MATURITY\x10\x02\x12\x11\n\rIMPLICIT_RATE\x10\x03\"-\n\x08RateType\x12\n\n\x06SIMPLE\x10\x00\x12\x15\n\x11YIELD_TO_MATURITY\x10\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'bond_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _COUPONDETAILS._serialized_start=80
  _COUPONDETAILS._serialized_end=285
  _COUPONDETAILS_COUPONRATETYPE._serialized_start=244
  _COUPONDETAILS_COUPONRATETYPE._serialized_end=285
  _COUPONSTREAM._serialized_start=287
  _COUPONSTREAM._serialized_end=373
  _BONDMARKETPRICE._serialized_start=376
  _BONDMARKETPRICE._serialized_end=526
  _BONDMARKETPRICE_QUOTETYPE._serialized_start=480
  _BONDMARKETPRICE_QUOTETYPE._serialized_end=526
  _BONDDETAILS._serialized_start=529
  _BONDDETAILS._serialized_end=1584
  _BONDDETAILS_ACCRETION._serialized_start=1141
  _BONDDETAILS_ACCRETION._serialized_end=1584
  _BONDDETAILS_ACCRETION_DEFINITIONTYPE._serialized_start=1447
  _BONDDETAILS_ACCRETION_DEFINITIONTYPE._serialized_end=1537
  _BONDDETAILS_ACCRETION_RATETYPE._serialized_start=1539
  _BONDDETAILS_ACCRETION_RATETYPE._serialized_end=1584
# @@protoc_insertion_point(module_scope)
