# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: warrant.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import currency_pb2 as currency__pb2
import date_pb2 as date__pb2
import matrix_pb2 as matrix__pb2
import offset_pb2 as offset__pb2
import output_pb2 as output__pb2
import yield_curve_pb2 as yield__curve__pb2
import stock_pb2 as stock__pb2
import enums_pb2 as enums__pb2
import model_parameters_pb2 as model__parameters__pb2
import object_info_pb2 as object__info__pb2
import warrant_call_schedule_pb2 as warrant__call__schedule__pb2
import ticker_pb2 as ticker__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\rwarrant.proto\x12\x06\x62\x61nchi\x1a\x0e\x63urrency.proto\x1a\ndate.proto\x1a\x0cmatrix.proto\x1a\x0coffset.proto\x1a\x0coutput.proto\x1a\x11yield_curve.proto\x1a\x0bstock.proto\x1a\x0b\x65nums.proto\x1a\x16model_parameters.proto\x1a\x11object_info.proto\x1a\x1bwarrant_call_schedule.proto\x1a\x0cticker.proto\x1a\x1egoogle/protobuf/wrappers.proto\"\x9e\x01\n\x10\x43\x61shlessExercise\x12\x30\n\x12table_offset_units\x18\x02 \x01(\x0e\x32\x14.banchi.Offset.Units\x12\x15\n\rtable_strikes\x18\x03 \x03(\x01\x12\x15\n\rtable_offsets\x18\x04 \x03(\x05\x12*\n\x0ctable_values\x18\x05 \x01(\x0b\x32\x14.banchi.DoubleMatrix\"\x7f\n\x14WarrantMergerDetails\x12\x1f\n\x17\x65xercise_only_on_merger\x18\x01 \x01(\x08\x12\x1c\n\x14new_term_post_merger\x18\x02 \x01(\x08\x12(\n\x10post_merger_term\x18\x03 \x01(\x0b\x32\x0e.banchi.Offset\"\x82\x03\n\x07Warrant\x12#\n\rmaturity_date\x18\x02 \x01(\x0b\x32\x0c.banchi.Date\x12\x16\n\x0e\x65xercise_price\x18\x03 \x01(\x01\x12.\n\x08\x65xercise\x18\x04 \x01(\x0e\x32\x1c.banchi.ExerciseScheduleType\x12*\n\x05\x63\x61lls\x18\x07 \x01(\x0b\x32\x1b.banchi.WarrantCallSchedule\x12\x33\n\x11\x63\x61shless_exercise\x18\x08 \x01(\x0b\x32\x18.banchi.CashlessExercise\x12\"\n\x08\x63urrency\x18\t \x01(\x0b\x32\x10.banchi.Currency\x12\x38\n\x12shares_per_warrant\x18\x0c \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12\x17\n\x0f\x61ttached_shares\x18\r \x01(\x01\x12,\n\x06merger\x18\x0f \x01(\x0b\x32\x1c.banchi.WarrantMergerDetailsJ\x04\x08\x01\x10\x02\"\x95\x02\n\x0eWarrantOutputs\x12\"\n\x04theo\x18\x01 \x01(\x0b\x32\x14.banchi.OutputDouble\x12#\n\x05\x64\x65lta\x18\n \x01(\x0b\x32\x14.banchi.OutputDouble\x12#\n\x05gamma\x18\x0b \x01(\x0b\x32\x14.banchi.OutputDouble\x12#\n\x05theta\x18\x0c \x01(\x0b\x32\x14.banchi.OutputDouble\x12\x36\n\x18implied_merger_intensity\x18\x14 \x01(\x0b\x32\x14.banchi.OutputDouble\x12\x38\n\x1aimplied_merger_probability\x18\x15 \x01(\x0b\x32\x14.banchi.OutputDouble\"\x98\x01\n\x0bWarrantInfo\x12\x0e\n\x06symbol\x18\x01 \x01(\t\x12\r\n\x05notes\x18\x0e \x01(\t\x12\x37\n\nadditional\x18\x0f \x03(\x0b\x32#.banchi.WarrantInfo.AdditionalEntry\x1a\x31\n\x0f\x41\x64\x64itionalEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xe2\x01\n\x12WarrantMergerModel\x12\'\n\nmodel_type\x18\x01 \x01(\x0e\x32\x13.banchi.MergerModel\x12\x11\n\tintensity\x18\x02 \x01(\x01\x12\x13\n\x0bprobability\x18\x03 \x01(\x01\x12<\n\x16post_merger_volatility\x18\x07 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12=\n\x17post_merger_stock_price\x18\x08 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\"B\n\x15WarrantTimeSeriesData\x12)\n\x0c\x63lose_prices\x18\x04 \x01(\x0b\x32\x13.banchi.DailyTicker\"\xd3\x03\n\x0bWarrantData\x12\"\n\x06object\x18\r \x01(\x0b\x32\x12.banchi.ObjectInfo\x12$\n\x0evaluation_date\x18\x02 \x01(\x0b\x32\x0c.banchi.Date\x12#\n\ninstrument\x18\x03 \x01(\x0b\x32\x0f.banchi.Warrant\x12\x1c\n\x05stock\x18\x04 \x01(\x0b\x32\r.banchi.Stock\x12\x36\n\x1ainstrument_risk_free_curve\x18\x05 \x01(\x0b\x32\x12.banchi.YieldCurve\x12\x31\n\x10model_parameters\x18\x06 \x01(\x0b\x32\x17.banchi.ModelParameters\x12\x14\n\x0cmarket_price\x18\t \x01(\x01\x12\x30\n\x0cmerger_model\x18\x0b \x01(\x0b\x32\x1a.banchi.WarrantMergerModel\x12\x32\n\x0btime_series\x18\x0e \x01(\x0b\x32\x1d.banchi.WarrantTimeSeriesData\x12\'\n\x07outputs\x18\x0f \x01(\x0b\x32\x16.banchi.WarrantOutputs\x12!\n\x04info\x18\x32 \x01(\x0b\x32\x13.banchi.WarrantInfoJ\x04\x08\x01\x10\x02\"4\n\x0eWarrantCalcSet\x12\"\n\x05\x63\x61lcs\x18\x01 \x03(\x0b\x32\x13.banchi.WarrantData*7\n\x0bMergerModel\x12\x08\n\x04NONE\x10\x00\x12\r\n\tINTENSITY\x10\x01\x12\x0f\n\x0bPROBABILITY\x10\x02\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'warrant_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _WARRANTINFO_ADDITIONALENTRY._options = None
  _WARRANTINFO_ADDITIONALENTRY._serialized_options = b'8\001'
  _MERGERMODEL._serialized_start=2193
  _MERGERMODEL._serialized_end=2248
  _CASHLESSEXERCISE._serialized_start=259
  _CASHLESSEXERCISE._serialized_end=417
  _WARRANTMERGERDETAILS._serialized_start=419
  _WARRANTMERGERDETAILS._serialized_end=546
  _WARRANT._serialized_start=549
  _WARRANT._serialized_end=935
  _WARRANTOUTPUTS._serialized_start=938
  _WARRANTOUTPUTS._serialized_end=1215
  _WARRANTINFO._serialized_start=1218
  _WARRANTINFO._serialized_end=1370
  _WARRANTINFO_ADDITIONALENTRY._serialized_start=1321
  _WARRANTINFO_ADDITIONALENTRY._serialized_end=1370
  _WARRANTMERGERMODEL._serialized_start=1373
  _WARRANTMERGERMODEL._serialized_end=1599
  _WARRANTTIMESERIESDATA._serialized_start=1601
  _WARRANTTIMESERIESDATA._serialized_end=1667
  _WARRANTDATA._serialized_start=1670
  _WARRANTDATA._serialized_end=2137
  _WARRANTCALCSET._serialized_start=2139
  _WARRANTCALCSET._serialized_end=2191
# @@protoc_insertion_point(module_scope)
