# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: trigger.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\rtrigger.proto\x12\x06\x62\x61nchi\"\xf6\x01\n\x07Trigger\"*\n\x04Type\x12\x08\n\x04NONE\x10\x00\x12\n\n\x06UPSIDE\x10\x01\x12\x0c\n\x08\x44OWNSIDE\x10\x02\"0\n\rGraceRequired\x12\x12\n\x0e\x44\x41YS_IN_PERIOD\x10\x00\x12\x0b\n\x07\x41VERAGE\x10\x01\"\x8c\x01\n\x0e\x43heckFrequency\x12\x16\n\x12\x43HECK_CONTINUOUSLY\x10\x00\x12\x11\n\rCHECK_MONTHLY\x10\x01\x12\x13\n\x0f\x43HECK_QUARTERLY\x10\x02\x12\x16\n\x12\x43HECK_SEMIANNUALLY\x10\x03\x12\x12\n\x0e\x43HECK_ANNUALLY\x10\x04\x12\x0e\n\nCHECK_ONCE\x10\rb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'trigger_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _TRIGGER._serialized_start=26
  _TRIGGER._serialized_end=272
  _TRIGGER_TYPE._serialized_start=37
  _TRIGGER_TYPE._serialized_end=79
  _TRIGGER_GRACEREQUIRED._serialized_start=81
  _TRIGGER_GRACEREQUIRED._serialized_end=129
  _TRIGGER_CHECKFREQUENCY._serialized_start=132
  _TRIGGER_CHECKFREQUENCY._serialized_end=272
# @@protoc_insertion_point(module_scope)
