# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cashflows.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import date_pb2 as date__pb2
import output_pb2 as output__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0f\x63\x61shflows.proto\x12\x06\x62\x61nchi\x1a\ndate.proto\x1a\x0coutput.proto\"\xcf\x01\n\x11ProjectedCashflow\x12\"\n\x0cpayment_date\x18\x01 \x01(\x0b\x32\x0c.banchi.Date\x12\x10\n\x08\x63\x61shflow\x18\x02 \x01(\x01\x12#\n\raccrual_start\x18\x03 \x01(\x0b\x32\x0c.banchi.Date\x12!\n\x0b\x61\x63\x63rual_end\x18\x04 \x01(\x0b\x32\x0c.banchi.Date\x12\x0c\n\x04rate\x18\x05 \x01(\x01\x12\n\n\x02pv\x18\x06 \x01(\x01\x12\"\n\x04type\x18\x07 \x01(\x0e\x32\x14.banchi.CashflowType\"f\n\x18OutputProjectedCashflows\x12(\n\x05value\x18\x01 \x03(\x0b\x32\x19.banchi.ProjectedCashflow\x12 \n\x04info\x18\x02 \x01(\x0b\x32\x12.banchi.OutputInfo*)\n\x0c\x43\x61shflowType\x12\n\n\x06\x43oupon\x10\x00\x12\r\n\tPrincipal\x10\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cashflows_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _CASHFLOWTYPE._serialized_start=367
  _CASHFLOWTYPE._serialized_end=408
  _PROJECTEDCASHFLOW._serialized_start=54
  _PROJECTEDCASHFLOW._serialized_end=261
  _OUTPUTPROJECTEDCASHFLOWS._serialized_start=263
  _OUTPUTPROJECTEDCASHFLOWS._serialized_end=365
# @@protoc_insertion_point(module_scope)
