# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: user_preferences.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import object_info_pb2 as object__info__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x16user_preferences.proto\x12\x06\x62\x61nchi\x1a\x11object_info.proto\" \n\x10ObjectGridColumn\x12\x0c\n\x04name\x18\x01 \x01(\t\"\xec\x01\n\x0eObjectGridView\x12)\n\x07\x63olumns\x18\x01 \x03(\x0b\x32\x18.banchi.ObjectGridColumn\x12\x18\n\x10sort_column_name\x18\x02 \x01(\t\x12<\n\x0esort_direction\x18\x03 \x01(\x0e\x32$.banchi.ObjectGridView.SortDirection\x12\x10\n\x08paginate\x18\x04 \x01(\x08\x12\x15\n\rrows_per_page\x18\x05 \x01(\x05\".\n\rSortDirection\x12\r\n\tASCENDING\x10\x00\x12\x0e\n\nDESCENDING\x10\x01\"\x9b\x03\n\x0fUserPreferences\x12\"\n\x06object\x18\x02 \x01(\x0b\x32\x12.banchi.ObjectInfo\x12,\n\x05theme\x18\x03 \x01(\x0e\x32\x1d.banchi.UserPreferences.Theme\x12\x15\n\rshow_tooltips\x18\x07 \x01(\x08\x12\x15\n\rtooltip_delay\x18\x08 \x01(\x01\x12G\n\x11object_grid_views\x18\x04 \x03(\x0b\x32,.banchi.UserPreferences.ObjectGridViewsEntry\x12$\n\x1c\x61nonymize_saved_calculations\x18\x05 \x01(\x08\x12%\n\x1dsave_convertible_calculations\x18\x06 \x01(\x08\x1aN\n\x14ObjectGridViewsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12%\n\x05value\x18\x02 \x01(\x0b\x32\x16.banchi.ObjectGridView:\x02\x38\x01\"\x1c\n\x05Theme\x12\t\n\x05LIGHT\x10\x00\x12\x08\n\x04\x44\x41RK\x10\x01J\x04\x08\x01\x10\x02\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'user_preferences_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _USERPREFERENCES_OBJECTGRIDVIEWSENTRY._options = None
  _USERPREFERENCES_OBJECTGRIDVIEWSENTRY._serialized_options = b'8\001'
  _OBJECTGRIDCOLUMN._serialized_start=53
  _OBJECTGRIDCOLUMN._serialized_end=85
  _OBJECTGRIDVIEW._serialized_start=88
  _OBJECTGRIDVIEW._serialized_end=324
  _OBJECTGRIDVIEW_SORTDIRECTION._serialized_start=278
  _OBJECTGRIDVIEW_SORTDIRECTION._serialized_end=324
  _USERPREFERENCES._serialized_start=327
  _USERPREFERENCES._serialized_end=738
  _USERPREFERENCES_OBJECTGRIDVIEWSENTRY._serialized_start=624
  _USERPREFERENCES_OBJECTGRIDVIEWSENTRY._serialized_end=702
  _USERPREFERENCES_THEME._serialized_start=704
  _USERPREFERENCES_THEME._serialized_end=732
# @@protoc_insertion_point(module_scope)
