# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: date.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\ndate.proto\x12\x06\x62\x61nchi\"*\n\x04\x44\x61te\x12\x15\n\rserial_number\x18\x01 \x01(\x05\x12\x0b\n\x03iso\x18\x02 \x01(\t\"6\n\tDateValue\x12\x1a\n\x04\x64\x61te\x18\x01 \x01(\x0b\x32\x0c.banchi.Date\x12\r\n\x05value\x18\x02 \x01(\x01\"A\n\x0eStartDateValue\x12 \n\nstart_date\x18\x01 \x01(\x0b\x32\x0c.banchi.Date\x12\r\n\x05value\x18\x02 \x01(\x01\"=\n\x0c\x45ndDateValue\x12\x1e\n\x08\x65nd_date\x18\x01 \x01(\x0b\x32\x0c.banchi.Date\x12\r\n\x05value\x18\x02 \x01(\x01*h\n\x08\x44\x61yCount\x12\x0b\n\x07\x41\x43T_365\x10\x00\x12\x0b\n\x07\x41\x43T_360\x10\x01\x12\x10\n\x0c\x41\x43T_ACT_ISDA\x10\x02\x12\x10\n\x0c\x41\x43T_ACT_ISMA\x10\x03\x12\x0e\n\nTHIRTY_360\x10\x04\x12\x0e\n\nTHIRTY_365\x10\x05\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'date_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _DAYCOUNT._serialized_start=252
  _DAYCOUNT._serialized_end=356
  _DATE._serialized_start=22
  _DATE._serialized_end=64
  _DATEVALUE._serialized_start=66
  _DATEVALUE._serialized_end=120
  _STARTDATEVALUE._serialized_start=122
  _STARTDATEVALUE._serialized_end=187
  _ENDDATEVALUE._serialized_start=189
  _ENDDATEVALUE._serialized_end=250
# @@protoc_insertion_point(module_scope)
