# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: offset.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0coffset.proto\x12\x06\x62\x61nchi\"\x84\x01\n\x06Offset\x12\r\n\x05value\x18\x01 \x01(\x05\x12#\n\x05units\x18\x02 \x01(\x0e\x32\x14.banchi.Offset.Units\"F\n\x05Units\x12\x08\n\x04\x44\x41YS\x10\x00\x12\x11\n\rBUSINESS_DAYS\x10\x01\x12\t\n\x05WEEKS\x10\x02\x12\n\n\x06MONTHS\x10\x03\x12\t\n\x05YEARS\x10\x04\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'offset_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _OFFSET._serialized_start=25
  _OFFSET._serialized_end=157
  _OFFSET_UNITS._serialized_start=87
  _OFFSET_UNITS._serialized_end=157
# @@protoc_insertion_point(module_scope)
