# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: convertible_calc.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
import object_info_pb2 as object__info__pb2
import convertible_pb2 as convertible__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x16\x63onvertible_calc.proto\x12\x06\x62\x61nchi\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x11object_info.proto\x1a\x11\x63onvertible.proto\"\xd9\x01\n\x18\x43onvertibleCalcOverrides\x12\x36\n\x10stock_spot_price\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12;\n\x15stock_volatility_flat\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12H\n\"instrument_credit_data_flat_spread\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\"\xdb\x01\n\x0f\x43onvertibleCalc\x12\"\n\x06object\x18\x02 \x01(\x0b\x32\x12.banchi.ObjectInfo\x12-\n\tcalc_time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0c\n\x04user\x18\x04 \x01(\t\x12,\n\x0b\x63onvertible\x18\x05 \x01(\x0b\x32\x17.banchi.ConvertibleData\x12\x33\n\toverrides\x18\x06 \x01(\x0b\x32 .banchi.ConvertibleCalcOverridesJ\x04\x08\x01\x10\x02\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'convertible_calc_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _CONVERTIBLECALCOVERRIDES._serialized_start=138
  _CONVERTIBLECALCOVERRIDES._serialized_end=355
  _CONVERTIBLECALC._serialized_start=358
  _CONVERTIBLECALC._serialized_end=577
# @@protoc_insertion_point(module_scope)
